@@ -1,5 +1,7 @@
 package v3
 
+import "reflect"
+
 // VulnerabilityMetadata represents all vulnerability data that is not necessary to perform package-to-vulnerability matching.
 type VulnerabilityMetadata struct {
 	ID           string   // The identifier of the vulnerability or advisory
@@ -65,7 +67,7 @@ func (v *VulnerabilityMetadata) Equal(vv VulnerabilityMetadata) bool {
 		}
 	}
 	for idx, item := range v.Cvss {
-		if item != vv.Cvss[idx] {
+		if !reflect.DeepEqual(item, vv.Cvss[idx]) {
 			return false
 		}
 	}
